pub struct LogContextStats {
pub polls: u64,
pub cpu_time: Duration,
pub elapsed: Duration,
pub db_queries: u64,
pub db_rows_fetched: u64,
pub db_time: Duration,
}Expand description
A snapshot of a log context statistics
Fields
polls: u64How many times the context was polled
cpu_time: DurationThe approximate CPU time spent in the context
elapsed: DurationHow much time elapsed since the context was created
db_queries: u64How many database queries were executed in the context
db_rows_fetched: u64The number of rows fetched from the database in the context
db_time: DurationThe cumulative wall-clock time spent executing database queries